==> toughpad-0.1.2.tar.gz: android/src/main/kotlin/ca/hivesolutions/toughpad/ToughpadPlugin.kt <==
package ca.hivesolutions.toughpad

import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

//import ca.hivesolutions.toughpad.HardwareButtonsSrv
import ca.hivesolutions.BarcodeReader.BarcodeReaderSrv
import android.app.Activity
import io.flutter.plugin.common.*
import java.util.concurrent.TimeUnit
import io.reactivex.rxkotlin.subscribeBy
import android.content.BroadcastReceiver;
import android.content.Context
import android.content.Intent
import com.panasonic.toughpad.android.api.appbtn.AppButtonManager;
import android.content.IntentFilter


public class ToughpadPlugin(activity: Activity, readBarcodesChannel: BasicMessageChannel<String>, hwButtonsChannel: BasicMessageChannel<String>): MethodCallHandler {
    private var barcodeReaderSrv: BarcodeReaderSrv = BarcodeReaderSrv();

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "barcode")
            val readBarcodesChannel = BasicMessageChannel<String>(registrar.messenger(), "readBarcodes", StringCodec.INSTANCE)
            val hwButtonsChannel = BasicMessageChannel<String>(registrar.messenger(), "buttonEvents", StringCodec.INSTANCE)
            channel.setMethodCallHandler(ToughpadPlugin(registrar.activity(), readBarcodesChannel, hwButtonsChannel))
        }
    }

    private fun registerReceiver(activity: Context, hwButtonsChannel: BasicMessageChannel<String>) {
        val broadcastReceiver = object : BroadcastReceiver() {
            override fun onReceive(context: Context, intent: Intent) {
                val buttonId = intent.getIntExtra("buttonId", 0)
                val buttonDown = intent.getIntExtra("buttonDown", 0)
                hwButtonsChannel.send(buttonId.toString()+","+buttonDown.toString()) { reply ->
                }
            }
        }
        activity.registerReceiver(broadcastReceiver, IntentFilter("BUTTON_EVENT"))
    }

    init {
        barcodeReaderSrv.init(activity)

        barcodeReaderSrv.barcode.subscribe(
                { readBarcode -> readBarcodesChannel.send(readBarcode){ reply ->}},
                { e -> println("Error: $e")},
                { println("Completed") })

        registerReceiver(activity, hwButtonsChannel)
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        if (call.method == "startBarcodeScan") {
            if (barcodeReaderSrv.hasHardware) {
                barcodeReaderSrv.reset()
                barcodeReaderSrv.startBarcodeScan()
            }
            result.success("")
        } else if (call.method == "stopBarcodeScan") {
            if (barcodeReaderSrv.hasHardware) {
                barcodeReaderSrv.stopBarcodeScan()
            }
            result.success("")
        } else if (call.method == "checkHardware") {
            var hardware = "0"
            if (barcodeReaderSrv.hasHardware) {
                hardware = "1"
            }
            result.success(hardware)
        } else {
            result.notImplemented()
        }
    }
}

==> toughpad-1.0.1.tar.gz: android/src/main/kotlin/ca/hivesolutions/toughpad/ToughpadPlugin.kt <==
package ca.hivesolutions.toughpad

import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

//import ca.hivesolutions.toughpad.HardwareButtonsSrv
import ca.hivesolutions.BarcodeReader.BarcodeReaderSrv
import android.app.Activity
import io.flutter.plugin.common.*
import java.util.concurrent.TimeUnit
import io.reactivex.rxkotlin.subscribeBy
import android.content.BroadcastReceiver;
import android.content.Context
import android.content.Intent
import com.panasonic.toughpad.android.api.appbtn.AppButtonManager;
import android.content.IntentFilter
import android.os.Bundle
import android.os.Handler
import java.util.*

public class ToughpadPlugin(activity: Activity, readBarcodesChannel: BasicMessageChannel<String>, hwButtonsChannel: BasicMessageChannel<String>): MethodCallHandler {
    private var barcodeReaderSrv: BarcodeReaderSrv = BarcodeReaderSrv();

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "barcode")
            val readBarcodesChannel = BasicMessageChannel<String>(registrar.messenger(), "readBarcodes", StringCodec.INSTANCE)
            val hwButtonsChannel = BasicMessageChannel<String>(registrar.messenger(), "buttonEvents", StringCodec.INSTANCE)
            channel.setMethodCallHandler(ToughpadPlugin(registrar.activity(), readBarcodesChannel, hwButtonsChannel))
        }
    }

    private fun registerReceiver(activity: Context, hwButtonsChannel: BasicMessageChannel<String>) {
        val broadcastReceiver = object : BroadcastReceiver() {
            override fun onReceive(context: Context, intent: Intent) {
                val buttonId = intent.getIntExtra("buttonId", 0)
                val buttonDown = intent.getIntExtra("buttonDown", 0)
                hwButtonsChannel.send(buttonId.toString()+","+buttonDown.toString()) { reply ->
                }
            }
        }
        activity.registerReceiver(broadcastReceiver, IntentFilter("BUTTON_EVENT"))
    }

    init {
        barcodeReaderSrv.init(activity)

        // barcodeReaderSrv.barcode.subscribe(
        //         { readBarcode -> readBarcodesChannel.send(readBarcode) { reply ->}},
        //         { e -> println("Error: $e")},
        //         { println("Completed") })


            // println("THREAD1 "+Thread.currentThread())

        // activity.runOnUiThread(java.lang.Runnable {
        //     // println("THREAD2 "+Thread.currentThread())

        //     override fun run() {
        //         println("THREAD3 "+Thread.currentThread())
        //     }
        // })

        barcodeReaderSrv.barcode.subscribe(
                { readBarcode -> activity.runOnUiThread(object : Runnable {
            override fun run() {
                // println("THREAD2: ${Thread.currentThread()}")
                // println("BARCODE: $readBarcode")
                readBarcodesChannel.send(readBarcode) { reply ->}
            }
        })},
                { e -> println("Error: $e")},
                { println("Completed") })

        // activity.runOnUiThread(object : Runnable {
        //     override fun run() {
        //         println("THREAD2: ${Thread.currentThread()}")
        //     }
        // })

        registerReceiver(activity, hwButtonsChannel)
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        if (call.method == "startBarcodeScan") {
            if (barcodeReaderSrv.hasHardware) {
                barcodeReaderSrv.reset()
                barcodeReaderSrv.startBarcodeScan()
            }
            result.success("")
        } else if (call.method == "stopBarcodeScan") {
            if (barcodeReaderSrv.hasHardware) {
                barcodeReaderSrv.stopBarcodeScan()
            }
            result.success("")
        } else if (call.method == "checkHardware") {
            var hardware = "0"
            if (barcodeReaderSrv.hasHardware) {
                hardware = "1"
            }
            result.success(hardware)
        } else {
            result.notImplemented()
        }
    }
}
